Pronounced /pɑɪlɑn/ cf OED pylon, 2a A small fixed pillar or column, used to support something for display.

Some development of this project was supported by a grant from the national sicence foundation: NFS BCS 1251807
